Learn R Programming

waterquality (version 1.0.0)

waterquality-package: waterquality: Satellite Derived Water Quality Detection Algorithms

Description

The main purpose of waterquality is to quickly and easily convert satellite-based reflectance imagery into one or many well-known water quality algorithms designed for the detection of harmful algal blooms or the following pigment proxies: chlorophyll-a, blue-green algae (phycocyanin), and turbidity. Johansen et al. (2019) tools:::Rd_expr_doi("10.21079/11681/35053").

Arguments

Author

Maintainer: Richard Johansen richard.a.johansen@erdc.dren.mil (ORCID)

Authors:

Other contributors:

  • U.S. Army Corps of Engineers [funder]

See Also